from django.core.exceptions import ImproperlyConfigured
from django.test import SimpleTestCase, override_settings

from ferda.plugins import CONFIG
from ferda.views.mixins import RegistryPluginMixin


class DummyBaseView(object):
    """Dummy base view."""

    def get_context_data(self):
        return {}


class DummyView(RegistryPluginMixin, DummyBaseView):
    """Dummy view."""


@override_settings(ROOT_URLCONF='ferda.tests.urls')
class TestRegistryPluginMixin(SimpleTestCase):
    """Test RegistryPluginMixin."""

    def setUp(self):
        self.view = DummyView()

    def test_ok(self):
        self.assertIn('registry', CONFIG)
        self.assertEqual(
            self.view.get_context_data(),
            {'active_plugin': 'registry', 'active_plugin_name': 'Registry'}
        )

    def test_exception(self):
        self.assertNotIn('dummy', CONFIG)
        self.view.plugin = 'dummy'
        with self.assertRaises(ImproperlyConfigured):
            self.view.get_context_data()
